@@ -7,7 +7,8 @@ from elementary.clients.slack.slack_message_builder import (
     MAX_ALERT_PREVIEW_BLOCKS,
     SlackMessageBuilder,
 )
-from elementary.utils.json_utils import prettify_json_str_set
+from elementary.monitor.alerts.schema.alert import AlertSuppressionSchema
+from elementary.utils.json_utils import prettify_json_str_set, try_load_json
 from elementary.utils.log import get_logger
 from elementary.utils.time import convert_utc_iso_format_to_datetime
 
@@ -18,6 +19,9 @@ class Alert:
     def __init__(
         self,
         id: str,
+        unique_id: str = None,
+        suppression_status: str = None,
+        sent_at: str = None,
         detected_at: str = None,
         database_name: str = None,
         schema_name: str = None,
@@ -27,12 +31,20 @@ class Alert:
         status: str = None,
         subscribers: Optional[List[str]] = None,
         slack_channel: Optional[str] = None,
+        alert_suppression_interval: int = 0,
+        alert_fields: Optional[list] = None,
         timezone: Optional[str] = None,
         meta: Optional[dict] = None,
+        model_meta: Optional[str] = None,
         **kwargs,
     ):
         self.slack_message_builder = SlackAlertMessageBuilder()
         self.id = id
+        self.unique_id = unique_id
+        self.alert_suppression = AlertSuppressionSchema(
+            suppression_status=suppression_status,
+            sent_at=sent_at,
+        )
         self.elementary_database_and_schema = elementary_database_and_schema
         self.detected_at_utc = None
         self.detected_at = None
@@ -50,9 +62,12 @@ class Alert:
         self.owners = owners
         self.tags = tags
         self.meta = meta
+        self.model_meta = try_load_json(model_meta) or {}
         self.status = status
         self.subscribers = subscribers
         self.slack_channel = slack_channel
+        self.alert_suppression_interval = alert_suppression_interval
+        self.alert_fields = alert_fields
 
     _LONGEST_MARKDOWN_SUFFIX_LEN = 3
     _CONTINUATION_SYMBOL = "..."
