@@ -3,7 +3,12 @@ import sys
 import click
 
 from elementary.config.config import Config
-from elementary.monitor.data_monitoring import DataMonitoring
+from elementary.monitor.data_monitoring.data_monitoring_alerts import (
+    DataMonitoringAlerts,
+)
+from elementary.monitor.data_monitoring.data_monitoring_report import (
+    DataMonitoringReport,
+)
 from elementary.tracking.anonymous_tracking import AnonymousTracking
 from elementary.utils import bucket_path
 from elementary.utils.log import get_logger
@@ -14,68 +19,129 @@ yaml = OrderedYaml()
 logger = get_logger(__name__)
 
 
+class Command:
+    MONITOR = "monitor"
+    REPORT = "monitor-report"
+    SEND_REPORT = "monitor-send-report"
+
+
 # Displayed in reverse order in --help.
-def common_options(func):
-    func = click.option(
-        "--disable-samples",
-        type=bool,
-        default=False,
-        help="Disable sampling of data. Useful if your data contains PII.",
-    )(func)
-    func = click.option(
-        "--dbt-quoting",
-        "-dq",
-        type=str,
-        default=None,
-        help="Use this variable to override dbt's default quoting behavior for the edr internal dbt package. Can be "
-        "one of the following: (1) all, (2) none, or (3) a combination of database,schema,identifier - for "
-        'example "schema,identifier"',
-    )(func)
-    func = click.option(
-        "--update-dbt-package",
-        "-u",
-        type=bool,
-        default=False,
-        help="Force downloading the latest version of the edr internal dbt package (usually this is not needed, "
-        "see documentation to learn more).",
-    )(func)
-    func = click.option(
-        "--days-back",
-        "-d",
-        type=int,
-        default=7,
-        help="Set a limit to how far back should edr collect data.",
-    )(func)
-    func = click.option(
-        "--env",
-        type=click.Choice(["dev", "prod"]),
-        default="dev",
-        help="This flag indicates if you are running Elementary in prod or dev environment and will be reflected accordingly in the report.",
-    )(func)
-    func = click.option(
-        "--config-dir",
-        "-c",
-        type=str,
-        default=Config.DEFAULT_CONFIG_DIR,
-        help="Global settings for edr are configured in a config.yml file in this directory "
-        "(if your config dir is ~/.edr, no need to provide this parameter as we use it as default).",
-    )(func)
-    func = click.option(
-        "--profile-target",
-        "-t",
-        type=str,
-        default=None,
-        help="If you have multiple targets for Elementary, optionally use this flag to choose a specific target.",
-    )(func)
-    func = click.option(
-        "--profiles-dir",
-        "-p",
-        type=str,
-        default=None,
-        help="Specify your profiles dir where a profiles.yml is located, this could be a dbt profiles dir "
-        "(if your profiles dir is ~/.dbt, no need to provide this parameter as we use it as default).",
-    )(func)
-    return func
+def common_options(cmd: str):
+    def decorator(func):
+        func = click.option(
+            "--disable-samples",
+            type=bool,
+            default=False,
+            help="Disable sampling of data. Useful if your data contains PII.",
+        )(func)
+        func = click.option(
+            "--dbt-quoting",
+            "-dq",
+            type=str,
+            default=None,
+            help="Use this variable to override dbt's default quoting behavior for the edr internal dbt package. Can be "
+            "one of the following: (1) all, (2) none, or (3) a combination of database,schema,identifier - for "
+            'example "schema,identifier"',
+        )(func)
+        func = click.option(
+            "--update-dbt-package",
+            "-u",
+            type=bool,
+            default=False,
+            help="Force downloading the latest version of the edr internal dbt package (usually this is not needed, "
+            "see documentation to learn more).",
+        )(func)
+        if cmd in (Command.MONITOR, Command.SEND_REPORT):
+            func = click.option(
+                "--slack-channel-name",
+                "-ch",
+                type=str,
+                default=None,
+                help="The Slack channel to send messages to.",
+            )(func)
+            func = click.option(
+                "--slack-token",
+                "-st",
+                type=str,
+                default=None,
+                help="The Slack token for your workspace.",
+            )(func)
+        if cmd in (Command.REPORT, Command.SEND_REPORT):
+            func = click.option(
+                "--exclude-elementary-models",
+                type=bool,
+                default=True,
+                help="Exclude Elementary's internal models from the report.",
+            )(func)
+            func = click.option(
+                "--project-name",
+                type=str,
+                default=None,
+                help="The project name to display in the report.",
+            )(func)
+        func = click.option(
+            "--days-back",
+            "-d",
+            type=int,
+            default=1 if cmd == Command.MONITOR else 7,
+            help="Set a limit to how far back should edr collect data.",
+        )(func)
+        func = click.option(
+            "--env",
+            type=click.Choice(["dev", "prod"]),
+            default="dev",
+            help="This flag indicates if you are running Elementary in prod or dev environment and will be reflected accordingly in the report.",
+        )(func)
+        func = click.option(
+            "--config-dir",
+            "-c",
+            type=click.Path(),
+            default=Config.DEFAULT_CONFIG_DIR,
+            help="Global settings for edr are configured in a config.yml file in this directory "
+            "(if your config dir is ~/.edr, no need to provide this parameter as we use it as default).",
+        )(func)
+        func = click.option(
+            "--profile-target",
+            "-t",
+            type=str,
+            default=None,
+            help="Which target to load for the given profile. "
+            "If specified, the target will be used for both the 'elementary' profile and your dbt project."
+            "Else, the default target will be used.",
+        )(func)
+        func = click.option(
+            "--profiles-dir",
+            "-p",
+            type=click.Path(exists=True),
+            default=None,
+            help="Which directory to look in for the profiles.yml file. "
+            "If not set, edr will look in the current working directory first, then HOME/.dbt/",
+        )(func)
+        func = click.option(
+            "--project-dir",
+            type=click.Path(exists=True),
+            default=None,
+            help="Which directory to look in for the dbt_project.yml file. Default is the current working directory.",
+        )(func)
+        func = click.option(
+            "--project-profile-target",
+            type=str,
+            default=None,
+            help="Which target to load for the given profile. "
+            "If specified, the target will be used for your dbt project."
+            "Else, the --profile-target will be used.",
+        )(func)
+        func = click.option(
+            "--select",
+            type=str,
+            default=None,
+            help="Filter the report by invocation_id / invocation_time / model_tag"
+            if cmd in (Command.REPORT, Command.SEND_REPORT)
+            else "Filter the alerts by tag / owner / model",
+        )(func)
+        return func
+
+    return decorator
 
 
 def get_cli_properties() -> dict:
@@ -99,27 +165,20 @@ def get_cli_properties() -> dict:
 
 
 @click.group(invoke_without_command=True)
-@common_options
+@common_options(Command.MONITOR)
 @click.option(
     "--slack-webhook",
-    "-s",
+    "-sw",
     type=str,
     default=None,
     help="A slack webhook URL for sending alerts to a specific channel.",
 )
 @click.option(
-    "--slack-token",
-    "-st",
+    "--deprecated-slack-webhook",
+    "-s",  # Deprecated - will be used for --select in the future
     type=str,
     default=None,
-    help="A slack token for sending alerts over slack.",
-)
-@click.option(
-    "--slack-channel-name",
-    "-ch",
-    type=str,
-    default=None,
-    help="The slack channel which all alerts will be sent to.",
+    help="DEPRECATED! - A slack webhook URL for sending alerts to a specific channel.",
 )
 @click.option(
     "--timezone",
@@ -153,31 +212,43 @@ def monitor(
     ctx,
     days_back,
     slack_webhook,
+    deprecated_slack_webhook,
     slack_token,
     slack_channel_name,
     timezone,
     config_dir,
     profiles_dir,
+    project_dir,
     update_dbt_package,
     full_refresh_dbt_package,
     dbt_quoting,
     profile_target,
+    project_profile_target,
     dbt_vars,
     test,
     disable_samples,
     env,
+    select,
 ):
     """
     Monitor your warehouse.
     """
-
     if ctx.invoked_subcommand is not None:
         return
+    if deprecated_slack_webhook is not None:
+        click.secho(
+            f'\n"-s" is deprecated and won\'t be supported in the near future.\n'
+            f'Please use "-sw" or "--slack-webhook" for passing Slack webhook.\n',
+            fg="bright_red",
+        )
+        slack_webhook = deprecated_slack_webhook
     vars = yaml.loads(dbt_vars) if dbt_vars else None
     config = Config(
         config_dir,
         profiles_dir,
+        project_dir,
         profile_target,
+        project_profile_target,
         dbt_quoting=dbt_quoting,
         slack_webhook=slack_webhook,
         slack_token=slack_token,
@@ -186,33 +257,35 @@ def monitor(
         env=env,
     )
     anonymous_tracking = AnonymousTracking(config)
+    anonymous_tracking.set_env("use_select", bool(select))
     anonymous_tracking.track_cli_start(
-        "monitor", get_cli_properties(), ctx.command.name
+        Command.MONITOR, get_cli_properties(), ctx.command.name
     )
     try:
         config.validate_monitor()
-        data_monitoring = DataMonitoring(
+        data_monitoring = DataMonitoringAlerts(
             config=config,
             tracking=anonymous_tracking,
             force_update_dbt_package=update_dbt_package,
             send_test_message_on_success=test,
             disable_samples=disable_samples,
+            filter=select,
         )
         success = data_monitoring.run_alerts(
             days_back, full_refresh_dbt_package, dbt_vars=vars
         )
         anonymous_tracking.track_cli_end(
-            "monitor", data_monitoring.properties(), ctx.command.name
+            Command.MONITOR, data_monitoring.properties(), ctx.command.name
         )
         if not success:
             sys.exit(1)
     except Exception as exc:
-        anonymous_tracking.track_cli_exception("monitor", exc, ctx.command.name)
+        anonymous_tracking.track_cli_exception(Command.MONITOR, exc, ctx.command.name)
         raise
 
 
 @monitor.command()
-@common_options
+@common_options(Command.REPORT)
 @click.option(
     "--executions-limit",
     "-el",
@@ -237,26 +310,17 @@ def monitor(
     default=True,
     help="Whether to open the report in the browser.",
 )
-@click.option(
-    "--exclude-elementary-models",
-    type=bool,
-    default=True,
-    help="Exclude Elementary's internal models from the report.",
-)
-@click.option(
-    "--project-name",
-    type=str,
-    help="The project name to display in the report.",
-)
 @click.pass_context
 def report(
     ctx,
     days_back,
     config_dir,
     profiles_dir,
+    project_dir,
     update_dbt_package,
     dbt_quoting,
     profile_target,
+    project_profile_target,
     executions_limit,
     file_path,
     disable_passed_test_metrics,
@@ -265,6 +329,7 @@ def report(
     disable_samples,
     project_name,
     env,
+    select,
 ):
     """
     Generate a local report of your warehouse.
@@ -272,21 +337,25 @@ def report(
     config = Config(
         config_dir,
         profiles_dir,
+        project_dir,
         profile_target,
+        project_profile_target,
         dbt_quoting=dbt_quoting,
         env=env,
     )
     anonymous_tracking = AnonymousTracking(config)
+    anonymous_tracking.set_env("use_select", bool(select))
     anonymous_tracking.track_cli_start(
-        "monitor-report", get_cli_properties(), ctx.command.name
+        Command.REPORT, get_cli_properties(), ctx.command.name
     )
     try:
         config.validate_report()
-        data_monitoring = DataMonitoring(
+        data_monitoring = DataMonitoringReport(
             config=config,
             tracking=anonymous_tracking,
             force_update_dbt_package=update_dbt_package,
             disable_samples=disable_samples,
+            filter=select,
         )
         generated_report_successfully, _ = data_monitoring.generate_report(
             days_back=days_back,
@@ -298,31 +367,17 @@ def report(
             project_name=project_name,
         )
         anonymous_tracking.track_cli_end(
-            "monitor-report", data_monitoring.properties(), ctx.command.name
+            Command.REPORT, data_monitoring.properties(), ctx.command.name
         )
         if not generated_report_successfully:
             sys.exit(1)
     except Exception as exc:
-        anonymous_tracking.track_cli_exception("monitor-report", exc, ctx.command.name)
+        anonymous_tracking.track_cli_exception(Command.REPORT, exc, ctx.command.name)
         raise
 
 
 @monitor.command()
-@common_options
-@click.option(
-    "--slack-token",
-    "-st",
-    type=str,
-    default=None,
-    help="A slack token for sending alerts over slack.",
-)
-@click.option(
-    "--slack-channel-name",
-    "-ch",
-    type=str,
-    default=None,
-    help="The slack channel which all alerts will be sent to.",
-)
+@common_options(Command.SEND_REPORT)
 @click.option(
     "--slack-file-name",
     type=str,
@@ -393,29 +448,20 @@ def report(
     default=False,
     help="If set to true elementary report won't show data metrics for passed tests (this can improve report creation time).",
 )
-@click.option(
-    "--exclude-elementary-models",
-    type=bool,
-    default=True,
-    help="Exclude Elementary's internal models from the report.",
-)
-@click.option(
-    "--project-name",
-    type=str,
-    help="The project name to display in the report.",
-)
 @click.pass_context
 def send_report(
     ctx,
     days_back,
     config_dir,
     profiles_dir,
+    project_dir,
     update_dbt_package,
     dbt_quoting,
     slack_token,
     slack_channel_name,
     slack_file_name,
     profile_target,
+    project_profile_target,
     executions_limit,
     bucket_file_path,
     disable_passed_test_metrics,
@@ -431,6 +477,7 @@ def send_report(
     disable_samples,
     project_name,
     env,
+    select,
 ):
     """
     Send the report to an external platform.
@@ -441,7 +488,9 @@ def send_report(
     config = Config(
         config_dir,
         profiles_dir,
+        project_dir,
         profile_target,
+        project_profile_target,
         dbt_quoting=dbt_quoting,
         slack_token=slack_token,
         slack_channel_name=slack_channel_name,
@@ -456,8 +505,9 @@ def send_report(
         env=env,
     )
     anonymous_tracking = AnonymousTracking(config)
+    anonymous_tracking.set_env("use_select", bool(select))
     anonymous_tracking.track_cli_start(
-        "monitor-send-report", get_cli_properties(), ctx.command.name
+        Command.SEND_REPORT, get_cli_properties(), ctx.command.name
     )
     try:
         config.validate_send_report()
@@ -468,11 +518,12 @@ def send_report(
             if bucket_file_path
             else slack_file_name
         )
-        data_monitoring = DataMonitoring(
+        data_monitoring = DataMonitoringReport(
             config=config,
             tracking=anonymous_tracking,
             force_update_dbt_package=update_dbt_package,
             disable_samples=disable_samples,
+            filter=select,
         )
         command_succeeded = False
         (
@@ -492,14 +543,14 @@ def send_report(
                 elementary_html_path, remote_file_path=bucket_file_path
             )
         anonymous_tracking.track_cli_end(
-            "monitor-send-report", data_monitoring.properties(), ctx.command.name
+            Command.SEND_REPORT, data_monitoring.properties(), ctx.command.name
         )
         if not command_succeeded:
             sys.exit(1)
 
     except Exception as exc:
         anonymous_tracking.track_cli_exception(
-            "monitor-send-report", exc, ctx.command.name
+            Command.SEND_REPORT, exc, ctx.command.name
         )
         raise
 
